Template Tags
=============

.. module:: feedaggregator.templatetags

Feedaggregator provide several custom template tags based on inclusion_tag to customize look'n feel. To use any of the following template tags you need to load them at the top of your template: ::

    {% load feedaggregator_tags %}

feedaggregator_feed_list
------------------------
    Show all the active feeds

feedaggregator_latest_items
---------------------------
    Show the latest items


feedaggregator_popular_tags
---------------------------
    Show the most used tags
